@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_ActionError.php,v 1.5 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_ActionError.php,v 1.6 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 include_once(ETHNA_BASE . '/class/Ethna_Error.php');
@@ -25,19 +25,13 @@ class Ethna_ActionError
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	array	顼֥Ȥΰ
-	 */
+	/**	@var	array	顼֥Ȥΰ */
 	var $error_list = array();
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form = null;
 
-	/**
-	 *	@var	object	Ethna_Logger		֥
-	 */
+	/**	@var	object	Ethna_Logger		֥ */
 	var $logger = null;
 	/**#@-*/
 
