@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_AppManager.php,v 1.3 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_AppManager.php,v 1.5 2005/01/12 17:10:31 fujimoto Exp $
  */
 
 /** ץꥱ󥪥֥Ⱦ: Ѳǽ */
@@ -21,28 +21,6 @@ define('OBJECT_SORT_ASC', 0);
 define('OBJECT_SORT_DESC', 1);
 
 
-/** ץꥱ󥪥֥ȸ: != */
-define('OBJECT_CONDITION_NE', 0);
-
-/** ץꥱ󥪥֥ȸ: == */
-define('OBJECT_CONDITION_EQ', 1);
-
-/** ץꥱ󥪥֥ȸ: LIKE */
-define('OBJECT_CONDITION_LIKE', 2);
-
-/** ץꥱ󥪥֥ȸ: > */
-define('OBJECT_CONDITION_GT', 3);
-
-/** ץꥱ󥪥֥ȸ: < */
-define('OBJECT_CONDITION_LT', 4);
-
-/** ץꥱ󥪥֥ȸ: >= */
-define('OBJECT_CONDITION_GE', 5);
-
-/** ץꥱ󥪥֥ȸ: <= */
-define('OBJECT_CONDITION_LE', 6);
-
-
 /** ץꥱ󥪥֥ȥݡȥץ: NULLץѥƥ̵Ѵ */
 define('OBJECT_IMPORT_IGNORE_NULL', 1);
 
@@ -64,39 +42,25 @@ class Ethna_AppManager
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Backend		backend֥
-	 */
+	/**	@var	object	Ethna_Backend		backend֥ */
 	var $backend;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥ */
 	var $config;
 
-	/**
-	 *  @var    object  Ethna_DB      DB֥
-	 */
+	/**  @var    object  Ethna_DB      DB֥ */
 	var $db;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥(ά) */
 	var $af;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
 	/**#@-*/
