@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_AppObject.php,v 1.7 2005/01/12 17:10:31 fujimoto Exp $
+ *	@version	$Id: Ethna_AppObject.php,v 1.8 2005/01/14 05:13:25 fujimoto Exp $
  */
 
 // {{{ Ethna_AppObject
@@ -941,7 +941,7 @@ class Ethna_AppObject
 		$column_id = $this->_getPrimaryTable() . "." . $id_def[0];	// any id columns will do
 
 		$condition = $this->_getSQL_SearchCondition($filter);
-		$sql = "SELECT DISTINCT COUNT($column_id) AS id_count FROM $tables $condition";
+		$sql = "SELECT COUNT(DISTINCT $column_id) AS id_count FROM $tables $condition";
 
 		return $sql;
 	}
@@ -1029,6 +1029,7 @@ class Ethna_AppObject
 
 		// 
 		$column = "";
+		$group_by = "";
 		if (is_null($keys)) {
 			$keys = array_keys($def);
 		}
@@ -1041,6 +1042,19 @@ class Ethna_AppObject
 			}
 			$t = isset($def[$key]['table']) ? $def[$key]['table'] : $p_table;
 			$column .= sprintf("%s.%s", $t, $key);
+
+			// եɤץ饤ޥ꡼ʤGROUP BY
+			if ((isset($def[$key]['table']) && $def[$key]['table'] == $p_table) ||
+				isset($def[$key]['table']) == false) {
+				if ($def[$key]['primary']) {
+					if ($group_by != "") {
+						$group_by .= ",";
+					} else {
+						$group_by .= "GROUP BY";
+					}
+					$group_by .= " $column";
+				}
+			}
 		}
 
 		$condition = $this->_getSQL_SearchCondition($filter);
@@ -1066,7 +1080,7 @@ class Ethna_AppObject
 			$limit .= sprintf("%d", $count);
 		}
 
-		$sql = "SELECT $column FROM $tables $condition $sort $limit";
+		$sql = "SELECT $column FROM $tables $condition $group_by $sort $limit";
 
 		return $sql;
 	}
