@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Controller.php,v 1.24 2004/12/23 06:03:12 fujimoto Exp $
+ *	@version	$Id: Ethna_Controller.php,v 1.27 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_Controller
@@ -23,29 +23,19 @@ class Ethna_Controller
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	string		ץꥱID
-	 */
+	/**	@var	string		ץꥱID */
 	var $appid = 'ETHNA';
 
-	/**
-	 *	@var	string		ץꥱ١ǥ쥯ȥ
-	 */
+	/**	@var	string		ץꥱ١ǥ쥯ȥ */
 	var $base = '';
 
-	/**
-	 *	@var	string		ץꥱ١URL
-	 */
+	/**	@var	string		ץꥱ١URL */
 	var	$url = '';
 
-	/**
-	 *	@var	string		ץꥱDSN(Data Source Name)
-	 */
+	/**	@var	string		ץꥱDSN(Data Source Name) */
 	var $dsn;
 
-	/**
-	 *	@var	array		ץꥱǥ쥯ȥ
-	 */
+	/**	@var	array		ץꥱǥ쥯ȥ */
 	var $directory = array(
 		'action'		=> 'app/action',
 		'etc'			=> 'etc',
@@ -59,152 +49,93 @@ class Ethna_Controller
 		'view'			=> 'app/view',
 	);
 
-	/**
-	 *	@var	array		DB
-	 */
+	/**	@var	array		DB */
 	var	$db = array(
 		''				=> DB_TYPE_RW,
 	);
 
-	/**
-	 *	@var	array		ĥ
-	 */
+	/**	@var	array		ĥ */
 	var $ext = array(
 		'php'			=> 'php',
 		'tpl'			=> 'tpl',
 	);
 
-	/**
-	 *	@var	array		饹
-	 */
+	/**	@var	array		饹 */
 	var $class = array(
+		'class'			=> 'Ethna_ClassFactory',
+		'backend'		=> 'Ethna_Backend',
 		'config'		=> 'Ethna_Config',
 		'db'			=> 'Ethna_DB',
+		'error'			=> 'Ethna_ActionError',
+		'form'			=> 'Ethna_ActionForm',
+		'i18n'			=> 'Ethna_I18N',
 		'logger'		=> 'Ethna_Logger',
+		'session'		=> 'Ethna_Session',
 		'sql'			=> 'Ethna_AppSQL',
+		'view'			=> 'Ethna_ViewClass',
 	);
 
-	/**
-	 *	@var	array		ե륿
-	 */
+	/**	@var	array		ե륿 */
 	var $filter = array(
 	);
 
-	/**
-	 *	@var	string		Ѹ
-	 */
+	/**	@var	string		Ѹ */
 	var $language;
 
-	/**
-	 *	@var	string		ƥ¦󥳡ǥ
-	 */
+	/**	@var	string		ƥ¦󥳡ǥ */
 	var	$system_encoding;
 
-	/**
-	 *	@var	string		饤¦󥳡ǥ
-	 */
+	/**	@var	string		饤¦󥳡ǥ */
 	var	$client_encoding;
 
-	/**
-	 *	@var	string		饤ȥ
-	 */
+	/**	@var	string		饤ȥ */
 	var $client_type;
 
-	/**
-	 *	@var	string	߼¹Υ̾
-	 */
+	/**	@var	string	߼¹Υ̾ */
 	var	$action_name;
 
-	/**
-	 *	@var	array	forward
-	 */
+	/**	@var	array	forward */
 	var $forward = array();
 
-	/**
-	 *	@var	array	action
-	 */
+	/**	@var	array	action */
 	var $action = array();
 
-	/**
-	 *	@var	array	soap action
-	 */
+	/**	@var	array	soap action */
 	var $soap_action = array();
 
-	/**
-	 *	@var	array	ץꥱޥ͡
-	 */
+	/**	@var	array	ץꥱޥ͡ */
 	var	$manager = array();
 
-	/**
-	 *	@var	array	smarty modifier
-	 */
+	/**	@var	array	smarty modifier */
 	var $smarty_modifier_plugin = array();
 
-	/**
-	 *	@var	array	smarty function
-	 */
+	/**	@var	array	smarty function */
 	var $smarty_function_plugin = array();
 
-	/**
-	 *	@var	array	smarty prefilter
-	 */
+	/**	@var	array	smarty prefilter */
 	var $smarty_prefilter_plugin = array();
 
-	/**
-	 *	@var	array	smarty postfilter
-	 */
+	/**	@var	array	smarty postfilter */
 	var $smarty_postfilter_plugin = array();
 
-	/**
-	 *	@var	array	smarty outputfilter
-	 */
+	/**	@var	array	smarty outputfilter */
 	var $smarty_outputfilter_plugin = array();
 
-	/**
-	 *	@var	object	Ethna_Backend	backend֥
-	 */
-	var $backend = null;
+	/**	@var	array	ե륿(Ethna_Filter֥Ȥ) */
+	var	$filter_chain = array();
 
-	/**
-	 *	@var	object	Ethna_I18N		i18n֥
-	 */
-	var $i18n = null;
+	/**	@var	object	Ethna_ClassFactory	饹եȥꥪ֥ */
+	var	$class_factory = null;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
-	var $action_error = null;
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
+	var	$action_form = null;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
-	var $action_form = null;
-
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
-	var $session = null;
-
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥ */
 	var	$config = null;
 
-	/**
-	 *	@var	object	Ethna_Logger		֥
-	 */
+	/**	@var	object	Ethna_Logger		֥ */
 	var	$logger = null;
 
-	/**
-	 *	@var	object	Ethna_AppSQL		SQL֥
-	 */
-	var	$sql = null;
-
-	/**
-	 *	@var	array	ե륿(Ethna_Filter֥Ȥ)
-	 */
-	var	$filter_chain = array();
-
 	/**#@-*/
 
 
@@ -218,6 +149,10 @@ class Ethna_Controller
 		$GLOBALS['controller'] =& $this;
 		$this->base = BASE;
 
+		// 饹եȥꥪ֥Ȥ
+		$class_factory = $this->class['class'];
+		$this->class_factory =& new $class_factory($this, $this->class);
+
 		// 顼ϥɥ
 		Ethna::setErrorCallback(array(&$this, 'handleError'));
 
@@ -239,25 +174,18 @@ class Ethna_Controller
 			}
 		}
 
-		$this->i18n =& new Ethna_I18N($this->getDirectory('locale'), $this->getAppId());
+		// 
 		list($this->language, $this->system_encoding, $this->client_encoding) = $this->_getDefaultLanguage();
 		$this->client_type = $this->_getDefaultClientType();
 
-		// եɤ߹
-		$config_class = $this->class['config'];
-		$this->config =& new $config_class($this);
+		$this->config =& $this->getConfig();
 		$this->dsn = $this->_prepareDSN();
 		$this->url = $this->config->get('url');
 
 		// ϳ
-		$logger_class = $this->class['logger'];
-		$this->logger =& new $logger_class($this);
+		$this->logger =& $this->getLogger();
 		$this->logger->begin();
 
-		// SQL֥
-		$sql_class = $this->class['sql'];
-		$this->sql =& new $sql_class($this);
-
 		// Ethnaޥ͡
 		$this->_activateEthnaManager();
 	}
@@ -314,6 +242,7 @@ class Ethna_Controller
 	function getDSN_persistent($type = "")
 	{
 		$key = sprintf("dsn%s_persistent", $type == "" ? "" : "_$type");
+
 		$dsn_persistent = $this->config->get($key);
 		if (is_null($dsn_persistent)) {
 			return false;
@@ -388,21 +317,6 @@ class Ethna_Controller
 		return (empty($this->directory['view']) ? ($this->base . (empty($this->base) ? '' : '/')) : ($this->directory['view'] . "/"));
 	}
 
-	/**
-	 *	ץꥱ󥯥饹֤
-	 *
-	 *	@access	public
-	 *	@param	string	$key	饹("config", "db", "logger", "sql")
-	 *	@return	string	$keyб饹̾(꤬ʤnull)
-	 */
-	function getClass($key)
-	{
-		if (isset($this->class[$key]) == false) {
-			return null;
-		}
-		return $this->class[$key];
-	}
-
 	/**
 	 *	ץꥱǥ쥯ȥ֤
 	 *
@@ -449,36 +363,14 @@ class Ethna_Controller
 	}
 
 	/**
-	 *	i18n֥ȤΥ(R)
+	 *	饹եȥꥪ֥ȤΥ(R)
 	 *
 	 *	@access	public
-	 *	@return	object	Ethna_I18N	i18n֥
+	 *	@return	object	Ethna_ClassFactory	饹եȥꥪ֥
 	 */
-	function &getI18N()
+	function &getClassFactory()
 	{
-		return $this->i18n;
-	}
-
-	/**
-	 *	ꥪ֥ȤΥ
-	 *
-	 *	@access	public
-	 *	@return	object	Ethna_Config	ꥪ֥
-	 */
-	function &getConfig()
-	{
-		return $this->config;
-	}
-
-	/**
-	 *	backend֥ȤΥ
-	 *
-	 *	@access	public
-	 *	@return	object	Ethna_Backend	backend֥
-	 */
-	function &getBackend()
-	{
-		return $this->backend;
+		return $this->class_factory;
 	}
 
 	/**
@@ -489,7 +381,7 @@ class Ethna_Controller
 	 */
 	function &getActionError()
 	{
-		return $this->action_error;
+		return $this->class_factory->getObject('error');
 	}
 
 	/**
@@ -500,18 +392,41 @@ class Ethna_Controller
 	 */
 	function &getActionForm()
 	{
+		// Ū˥饹եȥѤƤʤ
 		return $this->action_form;
 	}
 
 	/**
-	 *	å󥪥֥ȤΥ
+	 *	backend֥ȤΥ
 	 *
 	 *	@access	public
-	 *	@return	object	Ethna_Session		å󥪥֥
+	 *	@return	object	Ethna_Backend	backend֥
 	 */
-	function &getSession()
+	function &getBackend()
 	{
-		return $this->session;
+		return $this->class_factory->getObject('backend');
+	}
+
+	/**
+	 *	ꥪ֥ȤΥ
+	 *
+	 *	@access	public
+	 *	@return	object	Ethna_Config	ꥪ֥
+	 */
+	function &getConfig()
+	{
+		return $this->class_factory->getObject('config');
+	}
+
+	/**
+	 *	i18n֥ȤΥ(R)
+	 *
+	 *	@access	public
+	 *	@return	object	Ethna_I18N	i18n֥
+	 */
+	function &getI18N()
+	{
+		return $this->class_factory->getObject('i18n');
 	}
 
 	/**
@@ -522,7 +437,18 @@ class Ethna_Controller
 	 */
 	function &getLogger()
 	{
-		return $this->logger;
+		return $this->class_factory->getObject('logger');
+	}
+
+	/**
+	 *	å󥪥֥ȤΥ
+	 *
+	 *	@access	public
+	 *	@return	object	Ethna_Session		å󥪥֥
+	 */
+	function &getSession()
+	{
+		return $this->class_factory->getObject('session');
 	}
 
 	/**
@@ -533,7 +459,7 @@ class Ethna_Controller
 	 */
 	function &getSQL()
 	{
-		return $this->sql;
+		return $this->class_factory->getObject('sql');
 	}
 
 	/**
@@ -663,9 +589,9 @@ class Ethna_Controller
 		// ե륿
 		$this->_createFilterChain();
 
-		// prefilter
+		// ¹ե륿
 		for ($i = 0; $i < count($this->filter_chain); $i++) {
-			$this->filter_chain[$i]->prefilter();
+			$this->filter_chain[$i]->preFilter();
 		}
 
 		// trigger
@@ -677,9 +603,9 @@ class Ethna_Controller
 			$this->_trigger_AMF();
 		}
 
-		// postfilter
+		// ¹Ըե륿
 		for ($i = count($this->filter_chain) - 1; $i >= 0; $i--) {
-			$this->filter_chain[$i]->postfilter();
+			$this->filter_chain[$i]->postFilter();
 		}
 	}
 
@@ -713,32 +639,49 @@ class Ethna_Controller
 				$action_name = $fallback_action_name;
 			}
 		}
+
+		// ¹ե륿
+		for ($i = 0; $i < count($this->filter_chain); $i++) {
+			$r = $this->filter_chain[$i]->preActionFilter($action_name);
+			if ($r != null) {
+				$this->logger->log(LOG_DEBUG, 'action [%s] -> [%s] by %s', $action_name, $r, get_class($this->filter_chain[$i]));
+				$action_name = $r;
+			}
+		}
 		$this->action_name = $action_name;
 
 		// 
 		$this->_setLanguage($this->language, $this->system_encoding, $this->client_encoding);
 
 		// ֥
-		$this->action_error =& new Ethna_ActionError();
 		$form_name = $this->getActionFormName($action_name);
 		$this->action_form =& new $form_name($this);
-		$this->session =& new Ethna_Session($this->getAppId(), $this->getDirectory('tmp'), $this->logger);
 
 		// Хåɽ¹
-		$backend =& new Ethna_Backend($this);
-		$this->backend =& $backend;
+		$backend =& $this->getBackend();
 		$forward_name = $backend->perform($action_name);
 
+		// ¹Ըե륿
+		for ($i = count($this->filter_chain) - 1; $i >= 0; $i--) {
+			$r = $this->filter_chain[$i]->postActionFilter($action_name, $forward_name);
+			if ($r != null) {
+				$this->logger->log(LOG_DEBUG, 'forward [%s] -> [%s] by %s', $forward_name, $r, get_class($this->filter_chain[$i]));
+				$forward_name = $r;
+			}
+		}
+
 		// ȥꤹ(ץ)
 		$forward_name = $this->_sortForward($action_name, $forward_name);
 
 		if ($forward_name != null) {
-			$view_name = $this->getViewClassName($forward_name);
-			$view_class =& new $view_name($this->backend, $forward_name, $this->_getForwardPath($forward_name));
+			$view_class_name = $this->getViewClassName($forward_name);
+			$view_class =& new $view_class_name($backend, $forward_name, $this->_getForwardPath($forward_name));
 			$view_class->preforward();
+
 			// ߴ:(
-			if (is_subclass_of($view_class, 'Ethna_ViewClass') == false) {
-				$view_class =& new Ethna_ViewClass($this->backend, $forward_name, $this->_getForwardPath($forward_name));
+			$view_class_name = $this->class_factory->getObjectName('view');
+			if (is_subclass_of($view_class, $view_class_name) == false) {
+				$view_class =& new $view_class_name($backend, $forward_name, $this->_getForwardPath($forward_name));
 			}
 			$view_class->forward();
 		}
@@ -780,16 +723,13 @@ class Ethna_Controller
 	{
 		include_once('Ethna/contrib/amfphp/app/Gateway.php');
 
-		$this->action_error =& new Ethna_ActionError();
-
 		// CredentialإåǥåΤǤǤnull
 		$this->session = null;
 
 		$this->_setLanguage($this->language, $this->system_encoding, $this->client_encoding);
 
 		// backend֥
-		$backend =& new Ethna_Backend($this);
-		$this->backend =& $backend;
+		$backend =& $this->getBackend();
 
 		// 󥹥ץȤ򥤥󥯥롼
 		$this->_includeActionScript();
@@ -983,8 +923,9 @@ class Ethna_Controller
 		}
 		if (class_exists($action_obj['form_name']) == false) {
 			// ե९饹̤Ǥɤ
-			$this->logger->log(LOG_DEBUG, 'form class is not defined [%s] -> falling back to default [%s]', $action_obj['form_name'], 'Ethna_ActionForm');
-			$action_obj['form_name'] = 'Ethna_ActionForm';
+			$class_name = $this->class_factory->getObjectName('form');
+			$this->logger->log(LOG_DEBUG, 'form class is not defined [%s] -> falling back to default [%s]', $action_obj['form_name'], $class_name);
+			$action_obj['form_name'] = $class_name;
 		}
 
 		$action_obj['inspect'] = true;
@@ -1280,8 +1221,9 @@ class Ethna_Controller
 		if (class_exists($class_name)) {
 			return $class_name;
 		} else {
-			$this->logger->log(LOG_DEBUG, 'view class is not defined for [%s] -> use default [%s]', $forward_name, 'Ethna_ViewClass');
-			return 'Ethna_ViewClass';
+			$class_name = $this->class_factory->getObjectName('view');
+			$this->logger->log(LOG_DEBUG, 'view class is not defined for [%s] -> use default [%s]', $forward_name, $class_name);
+			return $class_name;
 		}
 	}
 
@@ -1438,6 +1380,7 @@ class Ethna_Controller
 		}
 
 		// default functions
+		$smarty->register_function('is_error', 'smarty_function_is_error');
 		$smarty->register_function('message', 'smarty_function_message');
 		$smarty->register_function('uniqid', 'smarty_function_uniqid');
 		$smarty->register_function('select', 'smarty_function_select');
@@ -1495,7 +1438,8 @@ class Ethna_Controller
 		$this->system_encoding = $system_encoding;
 		$this->client_encoding = $client_encoding;
 
-		$this->i18n->setLanguage($language, $system_encoding, $client_encoding);
+		$i18n =& $this->getI18N();
+		$i18n->setLanguage($language, $system_encoding, $client_encoding);
 	}
 
 	/**
