@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Filter.php,v 1.1 2004/12/09 05:35:21 fujimoto Exp $
+ *	@version	$Id: Ethna_Filter.php,v 1.3 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_Filter
@@ -26,24 +26,16 @@ class Ethna_Filter
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Controller	controller֥
-	 */
+	/**	@var	object	Ethna_Controller	controller֥ */
 	var	$controller;
 
-	/**
-	 *	@var	object	Ethna_Controller	controller֥($controllerξά)
-	 */
+	/**	@var	object	Ethna_Controller	controller֥($controllerξά) */
 	var	$ctl;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥ */
 	var	$config;
 
-	/**
-	 *	@var	object	Ethna_Logger		֥
-	 */
+	/**	@var	object	Ethna_Logger		֥ */
 	var $logger;
 
 	/**#@-*/
@@ -70,16 +62,40 @@ class Ethna_Filter
 	 *
 	 *	@access	public
 	 */
-	function prefilter()
+	function preFilter()
 	{
 	}
 
+	/**
+	 *	¹ե륿
+	 *
+	 *	@access	public
+	 *	@param	string	$action_name	¹Ԥ륢̾
+	 *	@return	string	null:ｪλ (string):¹Ԥ륢̾ѹ
+	 */
+	function preActionFilter($action_name)
+	{
+		return null;
+	}
+
+	/**
+	 *	¹Ըե륿
+	 *
+	 *	@access	public
+	 *	@param	string	$action_name	¹Ԥ줿̾
+	 *	@param	string	$forward_name	¹Ԥ줿󤫤
+	 */
+	function postActionFilter($action_name, $forward_name)
+	{
+		return null;
+	}
+
 	/**
 	 *	¹Ըե륿
 	 *
 	 *	@access	public
 	 */
-	function postfilter()
+	function postFilter()
 	{
 	}
 }
