@@ -4,7 +4,7 @@
  *
  *	@author		your name
  *	@package	{$project_id}
- *	@version	$Id: app.controller.php,v 1.7 2004/12/14 07:23:12 fujimoto Exp $
+ *	@version	$Id: app.controller.php,v 1.8 2005/01/06 17:44:24 fujimoto Exp $
  */
 
 /** ץꥱ١ǥ쥯ȥ */
@@ -118,10 +118,17 @@ class {$project_id}_Controller extends Ethna_Controller
 		 *	TODO: ꥯ饹饹SQL饹򥪡С饤
 		 *	ϲΥ饹̾˺줺ѹƤ
 		 */
-		'config'        => 'Ethna_Config',
+		'class'			=> 'Ethna_ClassFactory',
+		'backend'		=> 'Ethna_Backend',
+		'config'		=> 'Ethna_Config',
 		'db'			=> 'Ethna_DB',
-		'logger'        => 'Ethna_Logger',
-		'sql'           => 'Ethna_AppSQL',
+		'error'			=> 'Ethna_ActionError',
+		'form'			=> 'Ethna_ActionForm',
+		'i18n'			=> 'Ethna_I18N',
+		'logger'		=> 'Ethna_Logger',
+		'session'		=> 'Ethna_Session',
+		'sql'			=> 'Ethna_AppSQL',
+		'view'			=> 'Ethna_ViewClass',
 	);
 
 	/**
@@ -236,8 +243,9 @@ class {$project_id}_Controller extends Ethna_Controller
 		 * $smarty->assign_by_ref('session_id', session_id());
 		 *
 		 * // ե饰(true/false)
-		 * if ($this->session->isStart()) {
-		 * 	$smarty->assign_by_ref('login', $this->session->isStart());
+		 * $session =& $this->getClassFactory('session');
+		 * if ($session && $this->session->isStart()) {
+		 * 	$smarty->assign_by_ref('login', $session->isStart());
 		 * }
 		 */
 	}
